@@ -1,4 +1,4 @@
 ## Use to handle the CRAN check NOTE
 utils::globalVariables(
-  c("AMP", "DEL")
+  c("AMP", "DEL", "mean_rep")
 )
